==> jc-1.4.0.tar.gz: gnu/java/awt/BitwiseXORComposite__24IntContext.h <==
// class gnu.java.awt.BitwiseXORComposite$IntContext

// class file dependencies
// @dep_class d16c4b39930d90 gnu_java_awt_BitwiseXORComposite__24GeneralContext
// @dep_class f87161ca16360baf gnu_java_awt_BitwiseXORComposite__24IntContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_BitwiseXORComposite__24GeneralContext

#include "gnu/java/awt/BitwiseXORComposite__24GeneralContext.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_
#define _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$_init$502cd256b092363d(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern void _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$compose$eb43fc37b22d5535(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method_info$compose$eb43fc37b22d5535;

// Static methods
extern jboolean _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$isSupported$0ce12a29ec8d051a(_jc_env *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *);

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods {
	void	(*compose$eb43fc37b22d5535)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods	gnu_java_awt_BitwiseXORComposite__24IntContext;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs {
    _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24IntContext;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24IntContext;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object {
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite__24IntContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/BitwiseXORComposite__24IntContext.h <==
// class gnu.java.awt.BitwiseXORComposite$IntContext

// class file dependencies
// @dep_class d16c4b39930d90 gnu_java_awt_BitwiseXORComposite__24GeneralContext
// @dep_class f87161ca16360baf gnu_java_awt_BitwiseXORComposite__24IntContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_BitwiseXORComposite__24GeneralContext

#include "gnu/java/awt/BitwiseXORComposite__24GeneralContext.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_
#define _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$_init$502cd256b092363d(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$compose$eb43fc37b22d5535(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method_info$compose$eb43fc37b22d5535;

// Static methods
extern jboolean _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$method$isSupported$0ce12a29ec8d051a(_jc_env *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods {
	void	(*compose$eb43fc37b22d5535)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vmethods	gnu_java_awt_BitwiseXORComposite__24IntContext;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs {
    _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24IntContext;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24IntContext;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$object {
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite__24IntContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$vtype _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite__24IntContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite__24IntContext$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite__24IntContext_H_ */
